collective.teaser
=================

Teaser/Banner content type for Plone

This Plone add-on installs the content type teaser, which is meant to be used
for small advertisements on a homepage to advertise own or external content.

Randomly selected teasers will be shown in a Teaser portlet. An importance
level controls the frequency, how often teasers are shown - a teaser with
higher importance will be shown more frequently. If more teasers are shown in
portlets on a page, one teaser isn't shown twice.

If you need to show specific teasers only in specific portlets (e.g. to
distinguish between horizontal and vertical teasers), use the importance levels
or subject filter to assign teasers to those portlets.


Copyright
---------

Johannes Raggam, BlueDynamics Alliance - Author
Robert Niederreiter, BlueDynamics Alliance - Contributions
